"""
ChEMBL_search_protein_classification

Search protein classifications by target, classification type, or other criteria. To find a targe...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def ChEMBL_search_protein_classification(
    target_chembl_id: Optional[str] = None,
    protein_class_id: Optional[str] = None,
    limit: Optional[int] = 20,
    offset: Optional[int] = 0,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> dict[str, Any]:
    """
    Search protein classifications by target, classification type, or other criteria. To find a targe...

    Parameters
    ----------
    target_chembl_id : str
        Filter by target ChEMBL ID
    protein_class_id : str
        Filter by protein class ID
    limit : int

    offset : int

    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    dict[str, Any]
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {
            "name": "ChEMBL_search_protein_classification",
            "arguments": {
                "target_chembl_id": target_chembl_id,
                "protein_class_id": protein_class_id,
                "limit": limit,
                "offset": offset,
            },
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["ChEMBL_search_protein_classification"]
